/* A lexical scanner generated by flex */

/* Scanner skeleton version:
 * $Header: /home/daffy/u0/vern/flex/RCS/flex.skl,v 2.91 96/09/10 16:58:48 vern Exp $
 * $FreeBSD: src/usr.bin/lex/flex.skl,v 1.10.2.1.2.1 2009/10/25 01:10:29 kensmith Exp $
 */

#if defined(__FreeBSD__)
#include <sys/cdefs.h>
#else
#define __unused
#define __dead2
#endif

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5

#include <stdio.h>


/* cfront 1.2 defines "c_plusplus" instead of "__cplusplus" */
#ifdef c_plusplus
#ifndef __cplusplus
#define __cplusplus
#endif
#endif


#ifdef __cplusplus

#include <stdlib.h>
#include <unistd.h>

/* Use prototypes in function declarations. */
#define YY_USE_PROTOS

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_PROTOS
#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef __TURBOC__
 #pragma warn -rch
 #pragma warn -use
#include <io.h>
#include <stdlib.h>
#define YY_USE_CONST
#define YY_USE_PROTOS
#endif

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif


#ifdef YY_USE_PROTOS
#define YY_PROTO(proto) proto
#else
#define YY_PROTO(proto) ()
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#define YY_BUF_SIZE 16384

typedef struct yy_buffer_state *YY_BUFFER_STATE;

extern int yyleng;
extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

/* The funky do-while in the following #define is used to turn the definition
 * int a single C statement (which needs a semi-colon terminator).  This
 * avoids problems with code like:
 *
 * 	if ( condition_holds )
 *		yyless( 5 );
 *	else
 *		do_something_else();
 *
 * Prior to using the do-while the compiler would get upset at the
 * "else" because it interpreted the "if" statement as being all
 * done when it reached the ';' after the yyless() call.
 */

/* Return all but the first 'n' matched characters back to the input stream. */

#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
		*yy_cp = yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yy_c_buf_p = yy_cp = yy_bp + n - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yytext_ptr )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */
typedef unsigned int yy_size_t;


struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;
#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2
	};

static YY_BUFFER_STATE yy_current_buffer = 0;

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 */
#define YY_CURRENT_BUFFER yy_current_buffer


/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;

static int yy_n_chars;		/* number of characters read into yy_ch_buf */


int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 1;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart YY_PROTO(( FILE *input_file ));

void yy_switch_to_buffer YY_PROTO(( YY_BUFFER_STATE new_buffer ));
void yy_load_buffer_state YY_PROTO(( void ));
YY_BUFFER_STATE yy_create_buffer YY_PROTO(( FILE *file, int size ));
void yy_delete_buffer YY_PROTO(( YY_BUFFER_STATE b ));
void yy_init_buffer YY_PROTO(( YY_BUFFER_STATE b, FILE *file ));
void yy_flush_buffer YY_PROTO(( YY_BUFFER_STATE b ));
#define YY_FLUSH_BUFFER yy_flush_buffer( yy_current_buffer )

YY_BUFFER_STATE yy_scan_buffer YY_PROTO(( char *base, yy_size_t size ));
YY_BUFFER_STATE yy_scan_string YY_PROTO(( yyconst char *yy_str ));
YY_BUFFER_STATE yy_scan_bytes YY_PROTO(( yyconst char *bytes, int len ));

static void *yy_flex_alloc YY_PROTO(( yy_size_t ));
static void *yy_flex_realloc YY_PROTO(( void *, yy_size_t )) __unused;
static void yy_flex_free YY_PROTO(( void * ));

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! yy_current_buffer ) \
		yy_current_buffer = yy_create_buffer( yyin, YY_BUF_SIZE ); \
	yy_current_buffer->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! yy_current_buffer ) \
		yy_current_buffer = yy_create_buffer( yyin, YY_BUF_SIZE ); \
	yy_current_buffer->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (yy_current_buffer->yy_at_bol)


#define YY_USES_REJECT

#define yywrap() 1
#define YY_SKIP_YYWRAP
typedef unsigned char YY_CHAR;
FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;
typedef int yy_state_type;
extern int yylineno;
int yylineno = 1;
extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state YY_PROTO(( void ));
static yy_state_type yy_try_NUL_trans YY_PROTO(( yy_state_type current_state ));
static int yy_get_next_buffer YY_PROTO(( void ));
static void yy_fatal_error YY_PROTO(( yyconst char msg[] )) __dead2;

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 61
#define YY_END_OF_BUFFER 62
static yyconst short int yy_acclist[425] =
    {   0,
       62,   60,   61,   55,   60,   61,   59,   61,   60,   61,
       60,   61,   56,   60,   61,   56,   60,   61,   57,   60,
       61,   60,   61,   60,   61,   60,   61,   60,   61,   60,
       61,   60,   61,   60,   61,   60,   61,   60,   61,   60,
       61,   60,   61,   60,   61,   60,   61,   60,   61,   55,
       60,   61,   58,   59,   61,    3,   60,   61,    3,   60,
       61,    3,   60,   61,    3,   56,   60,   61,    3,   56,
       60,   61,    3,   57,   60,   61,    3,   60,   61,    3,
       60,   61,    3,   60,   61,    3,   60,   61,    3,   60,
       61,    3,   60,   61,    3,   60,   61,    3,   60,   61,

        3,   60,   61,    3,   60,   61,    3,   60,   61,    3,
       60,   61,    3,   60,   61,    3,   60,   61,   50,   61,
       49,   50,   61,   51,   61,   50,   61,   50,   61,   52,
       61,   53,   61,   61,   61,   54,   61,   55,    2,    1,
       56,   55,   58,    3,    3,    2,    3,    3,    3,    1,
        3,    3,    3,   56,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,   49,   52,   53,   54,    2,    1,
       24,   23,   11,   22,   43,    2,    3,    1,    3,    3,

       24,    3,    3,    3,    3,    3,    3,    3,    3,   23,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
       11,    3,    3,    3,   22,    3,   43,    3,    3,    3,
        3,    3,    3,    3,    3,    9,    6,   42,   25,   10,
        3,    9,    3,    3,    3,    3,    3,    3,    3,    3,
        6,    3,    3,    3,    3,   42,    3,    3,    3,    3,
        3,    3,    3,   25,    3,    3,    3,    3,    3,    3,
        3,   10,   44,   13,   21,   36,   27,   29,   12,    3,
        3,   13,    3,    3,    3,    3,    3,    3,   21,    3,
       36,    3,   27,    3,    3,    3,    3,    3,    3,    3,

        3,    3,    3,   29,    3,    3,   12,    3,    7,   40,
       26,    3,    3,    7,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,   26,    3,    3,    3,    3,
        4,   35,   34,   28,   39,    3,    3,    4,    3,    3,
        3,   35,    3,   34,    3,    3,    3,    3,    3,   28,
        3,    3,    3,    3,   39,   33,   32,    8,    3,   33,
        3,    3,   32,    3,    3,    3,    3,    3,    8,    3,
        3,    3,    3,   30,   41,   37,   38,    3,    3,    3,
        3,    3,    3,    3,    3,   30,    3,   41,    3,    3,
       37,    3,   38,    5,   14,   15,   17,   19,   16,   18,

       20,   31,    3,    5,    3,   14,    3,   15,    3,   17,
        3,   19,    3,   16,    3,   18,    3,   20,    3,   31,
       45,   46,   47,   48
    } ;

static yyconst short int yy_accept[490] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    7,    9,   11,   13,   16,   19,   22,
       24,   26,   28,   30,   32,   34,   36,   38,   40,   42,
       44,   46,   48,   50,   53,   56,   59,   62,   65,   69,
       73,   77,   80,   83,   86,   89,   92,   95,   98,  101,
      104,  107,  110,  113,  116,  119,  121,  124,  126,  128,
      130,  132,  134,  135,  136,  138,  139,  139,  140,  140,
      140,  141,  141,  142,  142,  142,  142,  142,  142,  142,
      142,  142,  142,  142,  142,  142,  142,  142,  142,  142,
      142,  142,  142,  142,  142,  142,  142,  142,  142,  142,

      142,  142,  142,  142,  143,  144,  145,  146,  148,  149,
      150,  152,  153,  155,  156,  157,  158,  159,  160,  161,
      162,  163,  164,  165,  166,  167,  168,  169,  170,  171,
      172,  173,  174,  175,  176,  177,  178,  179,  180,  181,
      182,  183,  184,  185,  186,  186,  186,  187,  188,  188,
      189,  190,  191,  192,  192,  192,  192,  192,  192,  192,
      192,  193,  193,  193,  193,  193,  193,  193,  193,  193,
      193,  194,  194,  194,  195,  196,  196,  196,  196,  196,
      196,  196,  196,  196,  198,  200,  202,  203,  204,  205,
      206,  207,  208,  209,  211,  212,  213,  214,  215,  216,

      217,  218,  219,  220,  222,  223,  224,  226,  228,  229,
      230,  231,  232,  233,  234,  235,  236,  236,  236,  237,
      237,  237,  237,  237,  237,  237,  237,  238,  238,  238,
      238,  239,  239,  239,  239,  239,  239,  239,  240,  240,
      240,  240,  240,  240,  240,  241,  243,  244,  245,  246,
      247,  248,  249,  250,  252,  253,  254,  255,  257,  258,
      259,  260,  261,  262,  263,  265,  266,  267,  268,  269,
      270,  271,  273,  274,  274,  274,  275,  275,  275,  275,
      275,  275,  276,  277,  278,  278,  278,  278,  278,  278,
      278,  278,  278,  278,  278,  279,  279,  280,  280,  281,

      283,  284,  285,  286,  287,  288,  290,  292,  294,  295,
      296,  297,  298,  299,  300,  301,  302,  303,  305,  306,
      308,  309,  309,  309,  310,  310,  310,  310,  310,  311,
      311,  311,  311,  311,  311,  311,  312,  312,  312,  312,
      312,  313,  315,  316,  317,  318,  319,  320,  321,  322,
      323,  324,  325,  327,  328,  329,  330,  331,  331,  331,
      332,  332,  332,  333,  334,  334,  334,  334,  334,  335,
      335,  335,  335,  336,  337,  339,  340,  341,  343,  345,
      346,  347,  348,  349,  351,  352,  353,  354,  356,  356,
      357,  357,  358,  358,  358,  358,  358,  359,  359,  359,

      359,  359,  361,  362,  364,  365,  366,  367,  368,  370,
      371,  372,  373,  374,  374,  374,  374,  374,  374,  374,
      374,  374,  375,  376,  376,  377,  378,  379,  380,  381,
      382,  383,  384,  385,  387,  389,  390,  392,  394,  394,
      395,  396,  397,  398,  399,  400,  401,  402,  403,  405,
      407,  409,  411,  413,  415,  417,  419,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  422,  423,  424,  425,  425
    } ;

static yyconst int yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    1,    1,    1,    1,    5,    1,
        1,    1,    1,    1,    1,    1,    6,    7,    8,    9,
       10,   11,   12,   13,   14,   15,   14,   16,    1,    1,
        1,    1,    1,    1,   17,   18,   19,   20,   21,   22,
       23,   24,   25,    1,   26,   27,   28,   29,   30,   31,
        1,   32,   33,   34,   35,   36,   37,   38,   39,   40,
        1,   41,    1,    1,   42,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst int yy_meta[43] =
    {   0,
        1,    2,    2,    1,    1,    1,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1
    } ;

static yyconst short int yy_base[500] =
    {   0,
        0,   41,   44,   85,   87,   89,   91,   93,  595,  594,
      596,  599,  593,  599,   93,   94,    0,  575,  599,   73,
      568,   83,   85,   87,  571,   73,   94,   90,  570,   98,
      101,  559,  572,  127,  599,    0,  134,  137,  172,  569,
        0,  116,  562,  126,  125,   91,  565,  116,  131,  133,
      564,  128,  134,  553,  566,  599,  580,  599,  564,  559,
        0,  577,  599,  575,  599,  575,  128,  599,  151,  152,
      599,  155,    0,  552,  553,  542,  553,  543,  537,  536,
      541,  537,  534,  539,  548,  535,  543,  530,  528,  154,
      550,  527,  525,  536,  528,  527,  514,  524,  518,  532,

      533,  530,  512,  165,  599,    0,  168,    0,  187,  192,
        0,  196,    0,  523,  524,  513,  524,  514,  508,  507,
      512,  508,  505,  510,  519,  506,  514,  501,  499,  180,
      521,  498,  496,  507,  499,  498,  485,  495,  489,  503,
      504,  501,  483,  516,  483,  485,    0,  513,  511,  599,
      169,  171,  599,  491,  495,  486,  493,  492,  487,  476,
      599,  487,  484,  481,  471,  481,  482,  467,  478,  468,
      599,  475,  462,  472,  599,  461,  472,  469,  464,  448,
      470,  446,  466,  200,  203,    0,  464,  468,  459,  466,
      465,  460,  449,    0,  460,  457,  454,  444,  454,  455,

      440,  451,  441,    0,  448,  435,  445,    0,  434,  445,
      442,  437,  421,  443,  419,  439,  438,  431,  599,  428,
      426,  423,  427,  415,  422,  409,  599,  417,  428,  410,
      445,  429,  207,  413,  414,  420,  425,  599,  399,  403,
      418,  413,  411,  415,  599,    0,  406,  404,  401,  405,
      393,  400,  387,    0,  395,  406,  388,  423,  407,  209,
      391,  392,  398,  403,    0,  377,  381,  396,  391,  389,
      393,    0,  599,  396,  389,  599,  372,  380,  375,  375,
      382,  599,  599,  599,  209,  383,  399,  398,  373,  370,
      384,  369,  374,  366,  599,  368,  599,  379,  372,    0,

      355,  363,  358,  358,  365,    0,    0,    0,  366,  382,
      381,  356,  353,  367,  352,  357,  349,    0,  351,    0,
      362,  339,  356,  599,  353,  353,  353,  353,  599,  351,
      362,  361,  342,  340,  336,  599,  337,  340,  342,  334,
      341,    0,  338,  338,  338,  338,  336,  347,  346,  327,
      325,  321,    0,  322,  325,  327,  319,  324,  314,  599,
      320,  312,  599,  599,  212,  213,  326,  321,  599,  319,
      306,  309,  599,  306,    0,  312,  304,    0,    0,  214,
      219,  318,  313,    0,  311,  298,  301,    0,  313,  599,
      302,  599,  317,  315,  315,  220,  599,  293,  294,  302,

      226,    0,  295,    0,  310,  308,  308,  228,    0,  286,
      287,  295,  234,  290,  293,  298,  303,  296,  236,  301,
      300,  599,  599,  276,  599,  599,  286,  291,  296,  289,
      237,  294,  293,    0,    0,  269,    0,    0,  271,  599,
      599,  599,  599,  599,  599,  599,  599,  599,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  257,  219,  271,
      265,  278,  278,  259,  274,  264,  265,  248,  247,  224,
      225,  271,  266,  265,  252,  229,  235,  226,  210,  196,
      181,  148,  101,  599,  599,  599,  599,  599,  256,  259,
      262,  265,  268,   98,  271,  274,  277,  280,  283

    } ;

static yyconst short int yy_def[500] =
    {   0,
      488,    1,  488,    3,  489,  489,  490,  490,  491,  491,
      488,  488,  488,  488,  492,  493,  494,  494,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  495,  496,  497,  495,   39,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  488,  488,  488,  488,  488,
      498,  488,  488,  499,  488,  488,  492,  488,  492,  493,
      488,  493,  494,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,

      488,  488,  488,  488,  488,  495,  496,  495,  496,  497,
      495,  497,   39,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  488,  488,  488,  498,  488,  499,  488,
      492,  493,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  496,  497,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,

      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  495,  495,

      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,

      488,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,    0,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488

    } ;

static yyconst short int yy_nxt[642] =
    {   0,
       12,   13,   14,   15,   16,   12,   17,   17,   17,   17,
       18,   17,   17,   17,   17,   19,   20,   21,   22,   23,
       12,   24,   25,   12,   26,   12,   12,   27,   12,   12,
       28,   29,   30,   31,   32,   12,   33,   12,   12,   12,
       12,   12,   34,   35,   36,   13,   14,   37,   38,   36,
       39,   39,   39,   39,   40,   39,   39,   39,   39,   41,
       42,   43,   44,   45,   36,   46,   47,   36,   48,   36,
       36,   49,   36,   36,   50,   51,   52,   53,   54,   36,
       55,   36,   36,   36,   36,   36,   34,   35,   57,   58,
       57,   58,   62,   63,   62,   63,   68,   75,   71,   79,

       73,   87,   80,   82,   76,   88,   59,   77,   59,   83,
       92,   84,   81,   85,   89,  124,   96,  125,   60,   93,
       60,   94,   97,   90,   91,   99,  487,   98,  104,  105,
      100,   68,  101,   69,   72,   67,   67,  108,   70,   70,
      115,  111,  119,  122,  127,  120,  136,  116,  128,  123,
      117,  129,  137,  132,  151,  121,   71,  138,  139,  152,
      130,  131,  133,  140,  134,  141,  104,  105,   69,   67,
       67,  108,   68,  169,  109,   71,  486,  112,  113,  113,
      113,  113,  113,  113,  113,  113,  113,  170,   67,   67,
      184,   69,   72,   70,   70,   72,  111,   70,   70,  202,

      185,   67,   67,  108,   70,   70,  485,  111,  109,   69,
      285,   72,  329,  203,  287,  288,  310,  311,  393,  395,
      405,  394,  396,  406,  484,  407,  483,  109,  408,  419,
      420,  421,  112,  425,  426,  460,  112,  431,  432,  433,
      109,  437,  438,  112,  444,  453,  472,  474,  445,  454,
      482,  481,  461,  480,  473,  475,   56,   56,   56,   61,
       61,   61,   64,   64,   64,   67,   67,   67,   70,   70,
       70,  106,  479,  106,  107,  107,  107,  110,  110,  110,
      147,  478,  147,  149,  149,  149,  477,  476,  471,  470,
      469,  468,  467,  466,  465,  464,  463,  462,  459,  458,

      457,  456,  455,  452,  451,  450,  449,  448,  447,  446,
      443,  442,  441,  440,  439,  436,  435,  434,  430,  429,
      428,  427,  424,  423,  422,  418,  417,  416,  415,  414,
      413,  412,  411,  410,  409,  404,  403,  402,  401,  400,
      399,  398,  397,  392,  391,  390,  389,  388,  387,  386,
      385,  384,  383,  382,  381,  380,  379,  378,  377,  376,
      375,  374,  373,  372,  371,  370,  369,  368,  367,  366,
      365,  364,  363,  362,  361,  360,  359,  358,  357,  356,
      355,  354,  353,  352,  351,  350,  349,  348,  347,  346,
      345,  344,  343,  342,  341,  340,  339,  338,  337,  336,

      335,  334,  333,  332,  331,  330,  328,  327,  326,  325,
      324,  323,  322,  321,  320,  319,  318,  317,  316,  315,
      314,  313,  312,  309,  285,  308,  307,  306,  305,  304,
      303,  302,  301,  300,  299,  298,  297,  296,  295,  294,
      293,  292,  291,  290,  289,  286,  285,  284,  283,  282,
      281,  280,  279,  278,  277,  276,  275,  274,  273,  272,
      271,  270,  269,  268,  267,  266,  265,  264,  263,  262,
      261,  260,  259,  258,  257,  256,  255,  254,  253,  252,
      251,  250,  249,  248,  247,  246,  245,  244,  243,  242,
      241,  240,  239,  238,  237,  236,  235,  234,  233,  232,

      231,  230,  229,  228,  227,  226,  225,  224,  223,  222,
      221,  220,  219,  150,  148,  218,  217,  144,  216,  215,
      214,  213,  212,  211,  210,  209,  208,  207,  206,  205,
      204,  201,  200,  199,  198,  197,  196,  195,  194,  193,
      192,  191,  190,  189,  188,  187,  186,  183,  182,  181,
      180,  179,  178,  177,  176,  175,  174,  173,  172,  171,
      168,  167,  166,  165,  164,  163,  162,  161,  160,  159,
      158,  157,  156,  155,  154,  153,   66,  150,  148,  146,
      145,  144,  143,  142,  135,  126,  118,  114,  103,  102,
       95,   86,   78,   74,   66,  488,   65,   65,   11,  488,

      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488
    } ;

static yyconst short int yy_chk[642] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    2,    2,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    4,    4,    5,    5,
        6,    6,    7,    7,    8,    8,   15,   20,   16,   22,

      494,   26,   22,   23,   20,   26,    5,   20,    6,   23,
       28,   24,   22,   24,   27,   46,   30,   46,    5,   28,
        6,   28,   30,   27,   27,   31,  483,   30,   34,   34,
       31,   67,   31,   15,   16,   37,   37,   37,   38,   38,
       42,   38,   44,   45,   48,   44,   52,   42,   48,   45,
       42,   49,   52,   50,   69,   44,   70,   52,   53,   72,
       49,   49,   50,   53,   50,   53,  104,  104,   67,  107,
      107,  107,  151,   90,   37,  152,  482,   38,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   90,  109,  109,
      109,   69,   70,  110,  110,   72,  110,  112,  112,  130,

      112,  184,  184,  184,  185,  185,  481,  185,  107,  151,
      285,  152,  285,  130,  233,  233,  260,  260,  365,  366,
      380,  365,  366,  380,  480,  381,  479,  109,  381,  396,
      396,  396,  110,  401,  401,  459,  112,  408,  408,  408,
      184,  413,  413,  185,  419,  431,  470,  471,  419,  431,
      478,  477,  459,  476,  470,  471,  489,  489,  489,  490,
      490,  490,  491,  491,  491,  492,  492,  492,  493,  493,
      493,  495,  475,  495,  496,  496,  496,  497,  497,  497,
      498,  474,  498,  499,  499,  499,  473,  472,  469,  468,
      467,  466,  465,  464,  463,  462,  461,  460,  458,  439,

      436,  433,  432,  430,  429,  428,  427,  424,  421,  420,
      418,  417,  416,  415,  414,  412,  411,  410,  407,  406,
      405,  403,  400,  399,  398,  395,  394,  393,  391,  389,
      387,  386,  385,  383,  382,  377,  376,  374,  372,  371,
      370,  368,  367,  362,  361,  359,  358,  357,  356,  355,
      354,  352,  351,  350,  349,  348,  347,  346,  345,  344,
      343,  341,  340,  339,  338,  337,  335,  334,  333,  332,
      331,  330,  328,  327,  326,  325,  323,  322,  321,  319,
      317,  316,  315,  314,  313,  312,  311,  310,  309,  305,
      304,  303,  302,  301,  299,  298,  296,  294,  293,  292,

      291,  290,  289,  288,  287,  286,  281,  280,  279,  278,
      277,  275,  274,  271,  270,  269,  268,  267,  266,  264,
      263,  262,  261,  259,  258,  257,  256,  255,  253,  252,
      251,  250,  249,  248,  247,  244,  243,  242,  241,  240,
      239,  237,  236,  235,  234,  232,  231,  230,  229,  228,
      226,  225,  224,  223,  222,  221,  220,  218,  217,  216,
      215,  214,  213,  212,  211,  210,  209,  207,  206,  205,
      203,  202,  201,  200,  199,  198,  197,  196,  195,  193,
      192,  191,  190,  189,  188,  187,  183,  182,  181,  180,
      179,  178,  177,  176,  174,  173,  172,  170,  169,  168,

      167,  166,  165,  164,  163,  162,  160,  159,  158,  157,
      156,  155,  154,  149,  148,  146,  145,  144,  143,  142,
      141,  140,  139,  138,  137,  136,  135,  134,  133,  132,
      131,  129,  128,  127,  126,  125,  124,  123,  122,  121,
      120,  119,  118,  117,  116,  115,  114,  103,  102,  101,
      100,   99,   98,   97,   96,   95,   94,   93,   92,   91,
       89,   88,   87,   86,   85,   84,   83,   82,   81,   80,
       79,   78,   77,   76,   75,   74,   66,   64,   62,   60,
       59,   57,   55,   54,   51,   47,   43,   40,   33,   32,
       29,   25,   21,   18,   13,   11,   10,    9,  488,  488,

      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488
    } ;

static yy_state_type yy_state_buf[YY_BUF_SIZE + 2], *yy_state_ptr;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yy_full_match; /* restore poss. backed-over text */ \
++yy_lp; \
goto find_rule; \
}
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "cue_scanner.l"
#define INITIAL 0
#line 2 "cue_scanner.l"
/*
 * Copyright (c) 2004, 2005, 2006, 2007, Svend Sorensen
 * Copyright (c) 2009, 2010 Jochen Keil
 * For license terms, see the file COPYING in this distribution.
 */

#include <stdlib.h>
#include <string.h>

#include "config.h"

#include "cd.h"
#include "cue_parser.h"

char buffer[PARSER_BUFFER];

int yylex(void);
#define YY_NO_INPUT 1
#define YY_NO_UNPUT 1
#define NAME 1

#define REM 2

#define RPG 3

#define SKIP 4

#line 764 "cue_scanner.c"

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap YY_PROTO(( void ));
#else
extern int yywrap YY_PROTO(( void ));
#endif
#endif

#ifndef YY_NO_UNPUT
static void yyunput YY_PROTO(( int c, char *buf_ptr ));
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy YY_PROTO(( char *, yyconst char *, int ));
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen YY_PROTO(( yyconst char * ));
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput YY_PROTO(( void ));
#else
static int input YY_PROTO(( void ));
#endif
#endif

#if YY_STACK_USED
static int yy_start_stack_ptr = 0;
static int yy_start_stack_depth = 0;
static int *yy_start_stack = 0;
#ifndef YY_NO_PUSH_STATE
static void yy_push_state YY_PROTO(( int new_state ));
#endif
#ifndef YY_NO_POP_STATE
static void yy_pop_state YY_PROTO(( void ));
#endif
#ifndef YY_NO_TOP_STATE
static int yy_top_state YY_PROTO(( void ));
#endif

#else
#define YY_NO_PUSH_STATE 1
#define YY_NO_POP_STATE 1
#define YY_NO_TOP_STATE 1
#endif

#ifdef YY_MALLOC_DECL
YY_MALLOC_DECL
#else
#if __STDC__
#ifndef __cplusplus
#include <stdlib.h>
#endif
#else
/* Just try to get by without declaring the routines.  This will fail
 * miserably on non-ANSI systems for which sizeof(size_t) != sizeof(int)
 * or sizeof(void*) != sizeof(int).
 */
#endif
#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */

#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( yy_current_buffer->yy_is_interactive ) \
		{ \
		int c = '*', n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else if ( ((result = fread( buf, 1, max_size, yyin )) == 0) \
		  && ferror( yyin ) ) \
		YY_FATAL_ERROR( "input in flex scanner failed" );
#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL int yylex YY_PROTO(( void ))
#endif

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		yy_current_buffer->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

YY_DECL
	{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;

#line 34 "cue_scanner.l"


#line 921 "cue_scanner.c"

	if ( yy_init )
		{
		yy_init = 0;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yy_start )
			yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! yy_current_buffer )
			yy_current_buffer =
				yy_create_buffer( yyin, YY_BUF_SIZE );

		yy_load_buffer_state();
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yy_start;
		yy_current_state += YY_AT_BOL();
		yy_state_ptr = yy_state_buf;
		*yy_state_ptr++ = yy_current_state;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 489 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 599 );

yy_find_action:
		yy_current_state = *--yy_state_ptr;
		yy_lp = yy_accept[yy_current_state];
goto find_rule; /* avoid `defined but not used' warning */
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yy_lp && yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yy_lp];
					{
					yy_full_match = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--yy_state_ptr;
			yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					++yylineno;
			}

do_action:	/* This label is used only to access EOF actions. */


		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
#line 37 "cue_scanner.l"
case 2:
YY_RULE_SETUP
#line 37 "cue_scanner.l"
{
		yylval.sval = strncpy(	buffer,
					++yytext,
					(yyleng > sizeof(buffer) ? sizeof(buffer) : yyleng));
		yylval.sval[yyleng - 2] = '\0';
		BEGIN(INITIAL);
		return STRING;
		}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 46 "cue_scanner.l"
{
		yylval.sval = strncpy(	buffer,
					yytext,
					(yyleng > sizeof(buffer) ? sizeof(buffer) : yyleng));
		yylval.sval[yyleng] = '\0';
		BEGIN(INITIAL);
		return STRING;
		}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 55 "cue_scanner.l"
{ BEGIN(NAME); return CATALOG; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 56 "cue_scanner.l"
{ BEGIN(NAME); return CDTEXTFILE; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 58 "cue_scanner.l"
{ BEGIN(NAME); return FFILE; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 59 "cue_scanner.l"
{ return BINARY; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 60 "cue_scanner.l"
{ return MOTOROLA; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 61 "cue_scanner.l"
{ return AIFF; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 62 "cue_scanner.l"
{ return WAVE; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 63 "cue_scanner.l"
{ return MP3; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 65 "cue_scanner.l"
{ return TRACK; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 66 "cue_scanner.l"
{ yylval.ival = MODE_AUDIO; return AUDIO; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 67 "cue_scanner.l"
{ yylval.ival = MODE_MODE1; return MODE1_2048; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 68 "cue_scanner.l"
{ yylval.ival = MODE_MODE1_RAW; return MODE1_2352; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 69 "cue_scanner.l"
{ yylval.ival = MODE_MODE2; return MODE2_2336; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 70 "cue_scanner.l"
{ yylval.ival = MODE_MODE2_FORM1; return MODE2_2048; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 71 "cue_scanner.l"
{ yylval.ival = MODE_MODE2_FORM2; return MODE2_2342; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 72 "cue_scanner.l"
{ yylval.ival = MODE_MODE2_FORM_MIX; return MODE2_2332; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 73 "cue_scanner.l"
{ yylval.ival = MODE_MODE2_RAW; return MODE2_2352; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 75 "cue_scanner.l"
{ return FLAGS; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 76 "cue_scanner.l"
{ yylval.ival = FLAG_PRE_EMPHASIS; return PRE; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 77 "cue_scanner.l"
{ yylval.ival = FLAG_COPY_PERMITTED; return DCP; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 78 "cue_scanner.l"
{ yylval.ival = FLAG_FOUR_CHANNEL; return FOUR_CH; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 79 "cue_scanner.l"
{ yylval.ival = FLAG_SCMS; return SCMS; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 81 "cue_scanner.l"
{ return PREGAP; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 82 "cue_scanner.l"
{ return INDEX; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 83 "cue_scanner.l"
{ return POSTGAP; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 85 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = PTI_TITLE;  return TITLE; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 86 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = PTI_PERFORMER;  return PERFORMER; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 87 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = PTI_SONGWRITER;  return SONGWRITER; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 88 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = PTI_COMPOSER;  return COMPOSER; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 89 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = PTI_ARRANGER;  return ARRANGER; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 90 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = PTI_MESSAGE;  return MESSAGE; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 91 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = PTI_DISC_ID;  return DISC_ID; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 92 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = PTI_GENRE;  return GENRE; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 93 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = PTI_TOC_INFO1;  return TOC_INFO1; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 94 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = PTI_TOC_INFO2;  return TOC_INFO2; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 95 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = PTI_UPC_ISRC;  return UPC_EAN; }
	YY_BREAK
case 40:
*yy_cp = yy_hold_char; /* undo effects of setting up yytext */
yy_c_buf_p = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 96 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = PTI_UPC_ISRC;  return ISRC; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 97 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = PTI_SIZE_INFO;  return SIZE_INFO; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 99 "cue_scanner.l"
{ BEGIN(NAME); return TRACK_ISRC; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 101 "cue_scanner.l"
{ BEGIN(REM); /* exclusive rules for special exceptions */ }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 103 "cue_scanner.l"
{ BEGIN(NAME); yylval.ival = REM_DATE; return DATE; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 104 "cue_scanner.l"
{ BEGIN(RPG); yylval.ival = REM_REPLAYGAIN_ALBUM_GAIN;
							return REPLAYGAIN_ALBUM_GAIN; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 106 "cue_scanner.l"
{ BEGIN(RPG); yylval.ival = REM_REPLAYGAIN_ALBUM_PEAK;
							return REPLAYGAIN_ALBUM_PEAK; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 108 "cue_scanner.l"
{ BEGIN(RPG); yylval.ival = REM_REPLAYGAIN_TRACK_GAIN;
							return REPLAYGAIN_TRACK_GAIN; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 110 "cue_scanner.l"
{ BEGIN(RPG); yylval.ival = REM_REPLAYGAIN_TRACK_PEAK;
							return REPLAYGAIN_TRACK_PEAK; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 113 "cue_scanner.l"
{ BEGIN(REM); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 114 "cue_scanner.l"
{ BEGIN(REM); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 115 "cue_scanner.l"
{ BEGIN(INITIAL); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 117 "cue_scanner.l"
{
		yylval.sval = strncpy(	buffer,
					yytext,
					(yyleng > sizeof(buffer) ? sizeof(buffer) : yyleng));
		yylval.sval[yyleng] = '\0';
		BEGIN(SKIP);
		return STRING;
		}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 126 "cue_scanner.l"
{ BEGIN(RPG); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 128 "cue_scanner.l"
{ BEGIN(INITIAL); yylineno++; return '\n'; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 130 "cue_scanner.l"
{ /* ignore whitespace */ }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 132 "cue_scanner.l"
{ yylval.ival = atoi(yytext); return NUMBER; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 133 "cue_scanner.l"
{ return yytext[0]; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 135 "cue_scanner.l"
{ yylineno++; /* blank line */ }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 136 "cue_scanner.l"
{ yylineno++; return '\n'; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 137 "cue_scanner.l"
{ fprintf(stderr, "bad character '%c'\n", yytext[0]); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 139 "cue_scanner.l"
ECHO;
	YY_BREAK
#line 1344 "cue_scanner.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(NAME):
			case YY_STATE_EOF(REM):
			case YY_STATE_EOF(RPG):
			case YY_STATE_EOF(SKIP):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( yy_current_buffer->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between yy_current_buffer and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yy_n_chars = yy_current_buffer->yy_n_chars;
			yy_current_buffer->yy_input_file = yyin;
			yy_current_buffer->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yy_c_buf_p <= &yy_current_buffer->yy_ch_buf[yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yy_c_buf_p = yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state();

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer() )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yy_did_buffer_switch_on_eof = 0;

				if ( yywrap() )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yy_c_buf_p = yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yy_c_buf_p =
					yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state();

				yy_cp = yy_c_buf_p;
				yy_bp = yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yy_c_buf_p =
				&yy_current_buffer->yy_ch_buf[yy_n_chars];

				yy_current_state = yy_get_previous_state();

				yy_cp = yy_c_buf_p;
				yy_bp = yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of yylex */


/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */

static int yy_get_next_buffer()
	{
	char *dest = yy_current_buffer->yy_ch_buf;
	char *source = yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yy_c_buf_p > &yy_current_buffer->yy_ch_buf[yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( yy_current_buffer->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yy_c_buf_p - yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yy_c_buf_p - yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( yy_current_buffer->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		yy_current_buffer->yy_n_chars = yy_n_chars = 0;

	else
		{
		int num_to_read =
			yy_current_buffer->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */
#ifdef YY_USES_REJECT
			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );
#else

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = yy_current_buffer;

			int yy_c_buf_p_offset =
				(int) (yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yy_flex_realloc( (void *) b->yy_ch_buf,
							 b->yy_buf_size + 2 );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = yy_current_buffer->yy_buf_size -
						number_to_move - 1;
#endif
			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&yy_current_buffer->yy_ch_buf[number_to_move]),
			yy_n_chars, num_to_read );

		yy_current_buffer->yy_n_chars = yy_n_chars;
		}

	if ( yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			yy_current_buffer->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	yy_n_chars += number_to_move;
	yy_current_buffer->yy_ch_buf[yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	yy_current_buffer->yy_ch_buf[yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yytext_ptr = &yy_current_buffer->yy_ch_buf[0];

	return ret_val;
	}


/* yy_get_previous_state - get the state just before the EOB char was reached */

static yy_state_type yy_get_previous_state()
	{
	yy_state_type yy_current_state;
	char *yy_cp;

	yy_current_state = yy_start;
	yy_current_state += YY_AT_BOL();
	yy_state_ptr = yy_state_buf;
	*yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yytext_ptr + YY_MORE_ADJ; yy_cp < yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 489 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
	}


/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */

#ifdef YY_USE_PROTOS
static yy_state_type yy_try_NUL_trans( yy_state_type yy_current_state )
#else
static yy_state_type yy_try_NUL_trans( yy_current_state )
yy_state_type yy_current_state;
#endif
	{
	int yy_is_jam;

	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 489 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 488);
	if ( ! yy_is_jam )
		*yy_state_ptr++ = yy_current_state;

	return yy_is_jam ? 0 : yy_current_state;
	}


#ifndef YY_NO_UNPUT
#ifdef YY_USE_PROTOS
static void yyunput( int c, char *yy_bp )
#else
static void yyunput( c, yy_bp )
int c;
char *yy_bp;
#endif
	{
	char *yy_cp = yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yy_hold_char;

	if ( yy_cp < yy_current_buffer->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yy_n_chars + 2;
		char *dest = &yy_current_buffer->yy_ch_buf[
					yy_current_buffer->yy_buf_size + 2];
		char *source =
				&yy_current_buffer->yy_ch_buf[number_to_move];

		while ( source > yy_current_buffer->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		yy_current_buffer->yy_n_chars =
			yy_n_chars = yy_current_buffer->yy_buf_size;

		if ( yy_cp < yy_current_buffer->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	if ( c == '\n' )
		--yylineno;

	yytext_ptr = yy_bp;
	yy_hold_char = *yy_cp;
	yy_c_buf_p = yy_cp;
	}
#endif	/* ifndef YY_NO_UNPUT */


#ifdef __cplusplus
static int yyinput()
#else
static int input()
#endif
	{
	int c;

	*yy_c_buf_p = yy_hold_char;

	if ( *yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yy_c_buf_p < &yy_current_buffer->yy_ch_buf[yy_n_chars] )
			/* This was really a NUL. */
			*yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = yy_c_buf_p - yytext_ptr;
			++yy_c_buf_p;

			switch ( yy_get_next_buffer() )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/* fall through */

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap() )
						return EOF;

					if ( ! yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yy_c_buf_p = yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yy_c_buf_p;	/* cast for 8-bit char's */
	*yy_c_buf_p = '\0';	/* preserve yytext */
	yy_hold_char = *++yy_c_buf_p;

	yy_current_buffer->yy_at_bol = (c == '\n');
	if ( yy_current_buffer->yy_at_bol )
		++yylineno;

	return c;
	}


#ifdef YY_USE_PROTOS
void yyrestart( FILE *input_file )
#else
void yyrestart( input_file )
FILE *input_file;
#endif
	{
	if ( ! yy_current_buffer )
		yy_current_buffer = yy_create_buffer( yyin, YY_BUF_SIZE );

	yy_init_buffer( yy_current_buffer, input_file );
	yy_load_buffer_state();
	}


#ifdef YY_USE_PROTOS
void yy_switch_to_buffer( YY_BUFFER_STATE new_buffer )
#else
void yy_switch_to_buffer( new_buffer )
YY_BUFFER_STATE new_buffer;
#endif
	{
	if ( yy_current_buffer == new_buffer )
		return;

	if ( yy_current_buffer )
		{
		/* Flush out information for old buffer. */
		*yy_c_buf_p = yy_hold_char;
		yy_current_buffer->yy_buf_pos = yy_c_buf_p;
		yy_current_buffer->yy_n_chars = yy_n_chars;
		}

	yy_current_buffer = new_buffer;
	yy_load_buffer_state();

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yy_did_buffer_switch_on_eof = 1;
	}


#ifdef YY_USE_PROTOS
void yy_load_buffer_state( void )
#else
void yy_load_buffer_state()
#endif
	{
	yy_n_chars = yy_current_buffer->yy_n_chars;
	yytext_ptr = yy_c_buf_p = yy_current_buffer->yy_buf_pos;
	yyin = yy_current_buffer->yy_input_file;
	yy_hold_char = *yy_c_buf_p;
	}


#ifdef YY_USE_PROTOS
YY_BUFFER_STATE yy_create_buffer( FILE *file, int size )
#else
YY_BUFFER_STATE yy_create_buffer( file, size )
FILE *file;
int size;
#endif
	{
	YY_BUFFER_STATE b;

	b = (YY_BUFFER_STATE) yy_flex_alloc( sizeof( struct yy_buffer_state ) );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yy_flex_alloc( b->yy_buf_size + 2 );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
	}


#ifdef YY_USE_PROTOS
void yy_delete_buffer( YY_BUFFER_STATE b )
#else
void yy_delete_buffer( b )
YY_BUFFER_STATE b;
#endif
	{
	if ( ! b )
		return;

	if ( b == yy_current_buffer )
		yy_current_buffer = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yy_flex_free( (void *) b->yy_ch_buf );

	yy_flex_free( (void *) b );
	}


#ifndef YY_ALWAYS_INTERACTIVE
#ifndef YY_NEVER_INTERACTIVE
extern int isatty YY_PROTO(( int ));
#endif
#endif

#ifdef YY_USE_PROTOS
void yy_init_buffer( YY_BUFFER_STATE b, FILE *file )
#else
void yy_init_buffer( b, file )
YY_BUFFER_STATE b;
FILE *file;
#endif


	{
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

#if YY_ALWAYS_INTERACTIVE
	b->yy_is_interactive = 1;
#else
#if YY_NEVER_INTERACTIVE
	b->yy_is_interactive = 0;
#else
	b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
#endif
#endif
	}


#ifdef YY_USE_PROTOS
void yy_flush_buffer( YY_BUFFER_STATE b )
#else
void yy_flush_buffer( b )
YY_BUFFER_STATE b;
#endif

	{
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == yy_current_buffer )
		yy_load_buffer_state();
	}


#ifndef YY_NO_SCAN_BUFFER
#ifdef YY_USE_PROTOS
YY_BUFFER_STATE yy_scan_buffer( char *base, yy_size_t size )
#else
YY_BUFFER_STATE yy_scan_buffer( base, size )
char *base;
yy_size_t size;
#endif
	{
	YY_BUFFER_STATE b;

	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yy_flex_alloc( sizeof( struct yy_buffer_state ) );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b );

	return b;
	}
#endif


#ifndef YY_NO_SCAN_STRING
#ifdef YY_USE_PROTOS
YY_BUFFER_STATE yy_scan_string( yyconst char *yy_str )
#else
YY_BUFFER_STATE yy_scan_string( yy_str )
yyconst char *yy_str;
#endif
	{
	int len;
	for ( len = 0; yy_str[len]; ++len )
		;

	return yy_scan_bytes( yy_str, len );
	}
#endif


#ifndef YY_NO_SCAN_BYTES
#ifdef YY_USE_PROTOS
YY_BUFFER_STATE yy_scan_bytes( yyconst char *bytes, int len )
#else
YY_BUFFER_STATE yy_scan_bytes( bytes, len )
yyconst char *bytes;
int len;
#endif
	{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;

	/* Get memory for full buffer, including space for trailing EOB's. */
	n = len + 2;
	buf = (char *) yy_flex_alloc( n );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < len; ++i )
		buf[i] = bytes[i];

	buf[len] = buf[len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
	}
#endif


#ifndef YY_NO_PUSH_STATE
#ifdef YY_USE_PROTOS
static void yy_push_state( int new_state )
#else
static void yy_push_state( new_state )
int new_state;
#endif
	{
	if ( yy_start_stack_ptr >= yy_start_stack_depth )
		{
		yy_size_t new_size;

		yy_start_stack_depth += YY_START_STACK_INCR;
		new_size = yy_start_stack_depth * sizeof( int );

		if ( ! yy_start_stack )
			yy_start_stack = (int *) yy_flex_alloc( new_size );

		else
			yy_start_stack = (int *) yy_flex_realloc(
					(void *) yy_start_stack, new_size );

		if ( ! yy_start_stack )
			YY_FATAL_ERROR(
			"out of memory expanding start-condition stack" );
		}

	yy_start_stack[yy_start_stack_ptr++] = YY_START;

	BEGIN(new_state);
	}
#endif


#ifndef YY_NO_POP_STATE
static void yy_pop_state()
	{
	if ( --yy_start_stack_ptr < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN(yy_start_stack[yy_start_stack_ptr]);
	}
#endif


#ifndef YY_NO_TOP_STATE
static int yy_top_state()
	{
	return yy_start_stack[yy_start_stack_ptr - 1];
	}
#endif

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

#ifdef YY_USE_PROTOS
static void yy_fatal_error( yyconst char msg[] )
#else
static void yy_fatal_error( msg )
char msg[];
#endif
	{
	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
	}



/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
		yytext[yyleng] = yy_hold_char; \
		yy_c_buf_p = yytext + n; \
		yy_hold_char = *yy_c_buf_p; \
		*yy_c_buf_p = '\0'; \
		yyleng = n; \
		} \
	while ( 0 )


/* Internal utility routines. */

#ifndef yytext_ptr
#ifdef YY_USE_PROTOS
static void yy_flex_strncpy( char *s1, yyconst char *s2, int n )
#else
static void yy_flex_strncpy( s1, s2, n )
char *s1;
yyconst char *s2;
int n;
#endif
	{
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
	}
#endif

#ifdef YY_NEED_STRLEN
#ifdef YY_USE_PROTOS
static int yy_flex_strlen( yyconst char *s )
#else
static int yy_flex_strlen( s )
yyconst char *s;
#endif
	{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
	}
#endif


#ifdef YY_USE_PROTOS
static void *yy_flex_alloc( yy_size_t size )
#else
static void *yy_flex_alloc( size )
yy_size_t size;
#endif
	{
	return (void *) malloc( size );
	}

#ifdef YY_USE_PROTOS
static void *yy_flex_realloc( void *ptr, yy_size_t size )
#else
static void *yy_flex_realloc( ptr, size )
void *ptr;
yy_size_t size;
#endif
	{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
	}

#ifdef YY_USE_PROTOS
static void yy_flex_free( void *ptr )
#else
static void yy_flex_free( ptr )
void *ptr;
#endif
	{
	free( ptr );
	}

#if YY_MAIN
int main()
	{
	yylex();
	return 0;
	}
#endif
#line 139 "cue_scanner.l"

